/*
** Module   : HandleCommon.java
** Abstract : A massive interface which groups together all attributes and
**            methods available via a handle.
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130112 Created initial version.
** 002 CS  20130204 Added conversion support for socket and 
**                  server-socket - moved sensitive related methods from
**                  CommonWidget in the Sensitive interface.
** 003 OM  20130129 Added TempTable and Buffer interface.
** 004 CS  20130213 Added conversion support for app server.
** 005 CA  20130221 Added missing interfaces.
** 006 OM  20130129 Added Dereferenceable interface.
** 007 OM  20130320 Added ResultListHandler interface. Sorted all interfaces alphabetically.
** 008 CS  20130403 Added ConectableServer and BufferHandle interfaces.
** 009 CA  20130813 Added support for the async request reosurce.
** 010 GES 20141110 Added LegacyLogManager.
*/

package com.goldencode.p2j.util;

import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.xml.*;

/**
 * This interface groups together all attributes and methods available via a
 * handle.  No explicit implementation exists for it, its purpose is only to
 * provide runtime error support, when the handle is either invalid or not
 * of the expected type. Thus, if one of the handle's unwrap APIs find the
 * handle invalid or of a different type than expected, the
 * {@link handle#invalidAttrAccessProxy} API is used to obtain a dynamic proxy,
 * with its implementation in the {@link handle} class.
 */
public interface HandleCommon
extends AsyncRequest,
        Buffer,
        BufferHandle,
        CommonErrorStatus,
        CommonField,
        CommonFileInfo,
        CommonHandle,
        CommonHandleChain,
        CommonLastEvent,
        CommonSession,
        CommonWidget,
        CommonWindow,
        Connectable,
        ConnectableServer,
        Dereferenceable,
        Errorable,
        FieldInterface,
        FirstLastProcedureAttribute,
        LegacyLogManager,
        P2JQuery,
        PersistentProcedure,
        ResultListHandler,
        SaxAttributes,
        SaxEntity,
        SaxReader,
        SaxWriter,
        Sensitive,
        Server,
        SOAPEntity,
        SOAPFault,
        SOAPHeader,
        SOAPHeaderEntry,
        Socket,
        SocketListener,
        SslServerAttribute,
        SubTypeAttribute,
        TempTable,
        XCommon,
        XDocument,
        XEntity,
        XNodeRef
{
}